Class: Object
Overview
This makes the d method available everywhere.
If you don't like that, then
don't require 'wrong', and include Wrong::D only in the modules you want to call d from
This makes the d method available everywhere.
If you don't like that, then
don't require 'wrong', and include Wrong::D only in the modules you want to call d from